@@ -7,6 +7,21 @@
 #
 get.pkg_search_paths <- function(pkg, vrs) {
 
+  #If base R, default library
+    if (pkg %in% base_pkg()) {
+      
+      #Get libpath
+        libp <- .libPaths()
+        
+      #Get last one
+        default_lib <- libp[length(libp)]
+        
+      #Add package to name
+        full_path <- paste0(default_lib , "/", pkg)
+      #End
+        return(full_path)
+        }
+  
   rv <- as.character(getRversion())
 
   # Get rid of patch version number
